@@ -1,6 +1,7 @@
-# --------------------------------------------------------------------------------
-# <copyright company="Aspose" file="GetStyleFromDocumentElementRequest.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# coding: utf-8
+# -----------------------------------------------------------------------------------
+# <copyright company="Aspose" file="get_style_from_document_element_request.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -9,10 +10,10 @@
 #  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 #  copies of the Software, and to permit persons to whom the Software is
 #  furnished to do so, subject to the following conditions:
-# 
+#
 #  The above copyright notice and this permission notice shall be included in all
 #  copies or substantial portions of the Software.
-# 
+#
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 #  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -21,15 +22,14 @@
 #  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 #  SOFTWARE.
 # </summary>
-# --------------------------------------------------------------------------------
-
+# -----------------------------------------------------------------------------------
 
 class GetStyleFromDocumentElementRequest(object):
     """
     Request model for get_style_from_document_element operation.
     Initializes a new instance.
     :param name The document name.
-    :param styled_node_path Path to the node of IStyledDocumentElement.
+    :param styled_node_path The path to the node that supports a style. Supported node types: ParagraphFormat, List, ListLevel, Table.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
